@@ -19,8 +19,8 @@
 
 #include "stylefactory.h"
 
-#include <qcolor.h>
-#include <qdatetime.h>
+#include <QColor>
+#include <QDateTime>
 #include <KoUnit.h>
 #include <kdebug.h>
 
@@ -711,9 +711,9 @@ PageStyle::PageStyle( StyleFactory * styleFactory, QDomElement & e, const uint i
 
         QTime time;
         time = time.addSecs( pageDuration.attribute("timer").toInt() );
-        QString hours( QString::number( time.hour() ).rightJustify( 2, '0' ) );
-        QString ms( QString::number( time.minute() ).rightJustify( 2, '0' ) );
-        QString sec( QString::number( time.second() ).rightJustify( 2, '0' ) );
+        QString hours( QString::number( time.hour() ).rightJustified( 2, '0' ) );
+        QString ms( QString::number( time.minute() ).rightJustified( 2, '0' ) );
+        QString sec( QString::number( time.second() ).rightJustified( 2, '0' ) );
 
 
         //ISO8601 chapter 5.5.3.2
@@ -727,7 +727,7 @@ PageStyle::PageStyle( StyleFactory * styleFactory, QDomElement & e, const uint i
         int tmp=0;
         if(pageEffect.hasAttribute("value"))
             tmp=pageEffect.attribute("value").toInt();
-        kdDebug(30518)<<" tmp :"<<tmp<<endl;
+        kDebug(30518)<<" tmp :"<<tmp;
         switch( tmp )
         {
         case -1:
@@ -755,7 +755,7 @@ PageStyle::PageStyle( StyleFactory * styleFactory, QDomElement & e, const uint i
         case 8:
         case 9:
         case 10:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 11:
             m_page_effect = "spiralin-left";
@@ -767,13 +767,13 @@ PageStyle::PageStyle( StyleFactory * styleFactory, QDomElement & e, const uint i
         case 16:
         case 17:
         case 18:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 19:
             m_page_effect = "fade-from-top";
             break;
         case 20:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 21:
             m_page_effect = "fade-from-bottom";
@@ -782,40 +782,40 @@ PageStyle::PageStyle( StyleFactory * styleFactory, QDomElement & e, const uint i
             m_page_effect = "roll-from-bottom";
             break;
         case 23:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 24:
             m_page_effect = "roll-from-right";
             break;
         case 25:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 26:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 27:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 28:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 29:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 30:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 31:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 32:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 33:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 34:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         case 35:
             m_page_effect = "dissolve";
@@ -833,10 +833,10 @@ PageStyle::PageStyle( StyleFactory * styleFactory, QDomElement & e, const uint i
             m_page_effect = "fade-from-upperleft";
             break;
         case 40:
-            kdDebug(30518)<<" this style is not defined :"<<tmp<<endl;
+            kDebug(30518)<<" this style is not defined :"<<tmp;
             break;
         default:
-            kdDebug(30518)<<" style page effect not define : "<<tmp<<endl;
+            kDebug(30518)<<" style page effect not define :"<<tmp;
             break;
         }
     }
@@ -1033,7 +1033,7 @@ GraphicStyle::GraphicStyle( StyleFactory * styleFactory, QDomElement & e, const
         }
 
     }
-    kdDebug(30518)<<" alignment :"<<m_textAlignment<<endl;
+    kDebug(30518)<<" alignment :"<<m_textAlignment;
 
     m_name = QString( "gr%1" ).arg( index );
     if ( !pen.isNull() )
@@ -1123,16 +1123,16 @@ GraphicStyle::GraphicStyle( StyleFactory * styleFactory, QDomElement & e, const
         switch ( direction )
         {
         case 1:
-            m_shadow_offset_x = "-" + distance;
-            m_shadow_offset_y = "-" + distance;
+            m_shadow_offset_x = '-' + distance;
+            m_shadow_offset_y = '-' + distance;
             break;
         case 2:
             m_shadow_offset_x = "0cm";
-            m_shadow_offset_y = "-" + distance;
+            m_shadow_offset_y = '-' + distance;
             break;
         case 3:
             m_shadow_offset_x = distance;
-            m_shadow_offset_y = "-" + distance;
+            m_shadow_offset_y = '-' + distance;
             break;
         case 4:
             m_shadow_offset_x = distance;
@@ -1147,11 +1147,11 @@ GraphicStyle::GraphicStyle( StyleFactory * styleFactory, QDomElement & e, const
             m_shadow_offset_y = distance;
             break;
         case 7:
-            m_shadow_offset_x = "-" + distance;
+            m_shadow_offset_x = '-' + distance;
             m_shadow_offset_y = distance;
             break;
         case 8:
-            m_shadow_offset_x = "-" + distance;
+            m_shadow_offset_x = '-' + distance;
             m_shadow_offset_y = "0cm";
             break;
         }
@@ -1377,7 +1377,7 @@ ParagraphStyle::ParagraphStyle( QDomElement & e, const uint index )
     {
         QDomElement s = shadow.toElement();
         QString distance = QString( "%1pt" ).arg( s.attribute( "distance" ) );
-        m_text_shadow = distance + " " + distance;
+        m_text_shadow = distance + ' ' + distance;
     }
 
     if ( !indents.isNull() )
