@@ -20,11 +20,11 @@
 #ifndef IMPORTFIELD_H
 #define IMPORTFIELD_H
 
-#include <qxml.h>
+#include <QtXml>
 
 QString getFootnoteFramesetName(const QString& id);
 bool ProcessField(QDomDocument& mainDocument,
-    QDomElement& variableElement, QString strType, const QXmlAttributes& attributes);
+    QDomElement& variableElement, const QString& strType, const QXmlAttributes& attributes);
 
 
 #endif /* IMPORTFIELD_H */
