@@ -1,11 +1,13 @@
+//Added by qt3to4:
+#include <QTextStream>
 
 #ifndef _KWORD13LAYOUT
 #define _KWORD13LAYOUT
 
 class QTextStream;
 
-#include <qstring.h>
-#include <qmap.h>
+#include <QString>
+#include <QMap>
 
 #include "kword13formatone.h"
 
@@ -15,7 +17,7 @@ class QTextStream;
 class KWord13Layout
 {
 public:
-    KWord13Layout( void );
+    explicit KWord13Layout( void );
     ~KWord13Layout( void );
     
 public:
