@@ -11,16 +11,16 @@
 
 int main(int argc, char* argv[])
 {
-	kdDebug(30522) << argv[1] << endl;
-	kdDebug(30522) << argv[2] << endl;
+	kDebug(30522) << argv[1];
+	kDebug(30522) << argv[2];
 
 	QString fileIn = argv[1];
 	QString fileOut = argv[2];
 	
-	kdDebug(30522) << "TEXGRAPH FILTER --> BEGIN" << endl;
+	kDebug(30522) <<"TEXGRAPH FILTER --> BEGIN";
 	Xml2LatexParser parser(fileIn, fileOut);
-	parser.analyse();
-	kdDebug(30522) << "---------- generate file -------------" << endl;
+	parser.analyze();
+	kDebug(30522) <<"---------- generate file -------------";
 	parser.generate();
-	kdDebug(30522) << "TEXGRAPH FILTER --> END" << endl;
+	kDebug(30522) <<"TEXGRAPH FILTER --> END";
 }
