@@ -4,7 +4,9 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
-   License version 2 as published by the Free Software Foundation.
+   version 2 of the License, or (at your option) version 3 or,
+   at the discretion of KDE e.V (which shall act as a proxy as in
+   section 14 of the GPLv3), any later version..
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "conversion.h"
@@ -24,7 +26,7 @@
 #include <wv2/fields.h>
 
 #include <kdebug.h>
-#include <qregexp.h>
+#include <QRegExp>
 #include <qdom.h>
 #include <klocale.h>
 
@@ -69,7 +71,7 @@ QColor Conversion::color(int number, int defaultcolor, bool defaultWhite)
 	    return Qt::lightGray;
 
 	default:
-            kdDebug(30513) << "Conversion::color: unknown color: " << number << endl;
+            kDebug(30513) <<"Conversion::color: unknown color:" << number;
 	    if(defaultcolor == -1)
 		return QColor("black");
 	    else
@@ -150,7 +152,7 @@ int Conversion::fillPatternStyle( int ipat )
     case 25: // Diagonal Cross
         return Qt::DiagCrossPattern;
     default:
-        kdWarning(30513) << "Unhandled undocumented SHD ipat value: " << ipat << endl;
+        kWarning(30513) << "Unhandled undocumented SHD ipat value: " << ipat;
         return Qt::NoBrush;
     }
 }
@@ -281,7 +283,7 @@ QString Conversion::lineSpacing( const wvWare::Word97::LSPD& lspd )
         // Better implement line-height-at-least like OOo has.
     }
     else
-        kdWarning(30513) << "Unhandled LSPD::fMultLinespace value: " << lspd.fMultLinespace << endl;
+        kWarning(30513) << "Unhandled LSPD::fMultLinespace value: " << lspd.fMultLinespace;
     return value;
 }
 
@@ -350,7 +352,7 @@ int Conversion::numberFormatCode( int nfc )
     case 0: // arabic
         return 1;
     }
-    kdWarning(30513) << k_funcinfo << "Unknown NFC: " << nfc << endl;
+    kWarning(30513) << "Unknown NFC: " << nfc;
     return 1;
 }
 
@@ -389,7 +391,7 @@ QString Conversion::headerTypeToFramesetName( unsigned char type )
     case wvWare::HeaderData::FooterFirst:
         return i18n("First Page Footer");
     }
-    return QString::null;
+    return QString();
 }
 
 bool Conversion::isHeader( unsigned char type )
@@ -408,7 +410,7 @@ int Conversion::headerMaskToHType( unsigned char mask )
     bool hasFirst = ( mask & wvWare::HeaderData::HeaderFirst );
     // Odd is always there. We have even!=odd only if Even is there too.
     bool hasEvenOdd = ( mask & wvWare::HeaderData::HeaderEven );
-    //kdDebug(30513) << k_funcinfo << " hasEvenOdd=" << hasEvenOdd << endl;
+    //kDebug(30513) <<" hasEvenOdd=" << hasEvenOdd;
     if ( hasFirst )
         return hasEvenOdd ? 1 : 2;
     return hasEvenOdd ? 3 : 0;
@@ -419,7 +421,7 @@ int Conversion::headerMaskToFType( unsigned char mask )
     bool hasFirst = ( mask & wvWare::HeaderData::FooterFirst );
     bool hasEvenOdd = ( mask & wvWare::HeaderData::FooterEven );
     // Odd is always there. We have even!=odd only if Even is there too.
-    kdDebug(30513) << k_funcinfo << " hasEvenOdd=" << hasEvenOdd << endl;
+    kDebug(30513) <<" hasEvenOdd=" << hasEvenOdd;
     if ( hasFirst )
         return hasEvenOdd ? 1 : 2;
     return hasEvenOdd ? 3 : 0;
@@ -452,7 +454,7 @@ int Conversion::fldToFieldType( const wvWare::FLD* fld )
     }
 
     if( m_fieldType < 0 )
-        kdDebug(30513) << "unhandled field: fld.ftl: " << (int)fld->flt << endl;
+        kDebug(30513) <<"unhandled field: fld.ftl:" << (int)fld->flt;
 
     return m_fieldType;
 }
