@@ -4,7 +4,9 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
-   License version 2 as published by the Free Software Foundation.
+   version 2 of the License, or (at your option) version 3 or,
+   at the discretion of KDE e.V (which shall act as a proxy as in
+   section 14 of the GPLv3), any later version..
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,7 +31,7 @@
 #include <wv2/parser.h>
 #include <wv2/fields.h>
 
-#include <qfont.h>
+#include <QFont>
 #include <qfontinfo.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -123,10 +125,10 @@ void KWordTextHandler::footnoteFound( wvWare::FootnoteData::Type type,
     footnoteElem.setAttribute( "numberingtype", autoNumbered ? "auto" : "manual" );
     if ( type == wvWare::FootnoteData::Endnote )
         // Keep name in sync with Document::startFootnote
-        footnoteElem.setAttribute( "frameset", i18n("Endnote %1").arg( ++m_endNoteNumber ) );
+        footnoteElem.setAttribute( "frameset", i18n("Endnote %1", ++m_endNoteNumber ) );
     else
         // Keep name in sync with Document::startFootnote
-        footnoteElem.setAttribute( "frameset", i18n("Footnote %1").arg( ++m_footNoteNumber ) );
+        footnoteElem.setAttribute( "frameset", i18n("Footnote %1", ++m_footNoteNumber ) );
     varElem.appendChild( footnoteElem );
 
     // Remember to parse the footnote text later
@@ -160,7 +162,7 @@ void KWordTextHandler::tableRowFound( const wvWare::TableRowFunctor& functor, wv
         paragraphStart( 0L );
         static int s_tableNumber = 0;
         m_currentTable = new KWord::Table();
-        m_currentTable->name = i18n("Table %1").arg( ++s_tableNumber );
+        m_currentTable->name = i18n("Table %1", ++s_tableNumber );
         insertAnchor( m_currentTable->name );
     }
 
@@ -181,7 +183,7 @@ void KWordTextHandler::pictureFound( const wvWare::PictureFunctor& pictureFuncto
     QString pictureName = "pictures/picture";
     pictureName += QString::number( s_pictureNumber ); // filenames start at 0
     // looks better to the user if frame names start at 1
-    QString frameName = i18n("Picture %1").arg( ++s_pictureNumber );
+    QString frameName = i18n("Picture %1", ++s_pictureNumber );
     insertAnchor( frameName );
 
     switch ( picf->mfp.mm ) {
@@ -230,7 +232,7 @@ void KWordTextHandler::paragraphStart( wvWare::SharedPtr<const wvWare::Paragraph
     if ( m_bInParagraph )
         paragraphEnd();
     m_bInParagraph = true;
-    //kdDebug(30513) << "paragraphStart. style index:" << paragraphProperties->pap().istd << endl;
+    //kDebug(30513) <<"paragraphStart. style index:" << paragraphProperties->pap().istd;
     m_formats = mainDocument().createElement( "FORMATS" );
     m_paragraphProperties = paragraphProperties;
     const wvWare::StyleSheet& styles = m_parser->styleSheet();
@@ -295,7 +297,7 @@ void KWordTextHandler::fieldEnd( const wvWare::FLD* /*fld*/, wvWare::SharedPtr<c
 void KWordTextHandler::runOfText( const wvWare::UString& text, wvWare::SharedPtr<const wvWare::Word97::CHP> chp )
 {
     QConstString newText( Conversion::string( text ) );
-    //kdDebug(30513) << "runOfText: " << newText.string() << endl;
+    //kDebug(30513) <<"runOfText:" << newText.string();
 
     // text after fieldStart and before fieldSeparator is useless
     if( m_insideField && !m_fieldAfterSeparator ) return;
@@ -348,7 +350,7 @@ void KWordTextHandler::writeFormat( QDomElement& parentElement, const wvWare::Wo
 
     if ( !refChp || refChp->hps != chp->hps )
     {
-        //kdDebug(30513) << "        font size: " << chp->hps/2 << endl;
+        //kDebug(30513) <<"        font size:" << chp->hps/2;
         QDomElement fontSize( mainDocument().createElement( "SIZE" ) );
         fontSize.setAttribute( "value", (int)(chp->hps / 2) ); // hps is in half points
         format.appendChild( fontSize );
@@ -484,14 +486,14 @@ QString KWordTextHandler::getFont(unsigned fc) const
 {
     Q_ASSERT( m_parser );
     if ( !m_parser )
-        return QString::null;
+        return QString();
     const wvWare::Word97::FFN& ffn ( m_parser->font( fc ) );
 
     QConstString fontName( Conversion::string( ffn.xszFfn ) );
     QString font = fontName.string();
 
 #ifdef FONT_DEBUG
-    kdDebug(30513) << "    MS-FONT: " << font << endl;
+    kDebug(30513) <<"    MS-FONT:" << font;
 #endif
 
     static const unsigned ENTRIES = 6;
@@ -515,7 +517,7 @@ QString KWordTextHandler::getFont(unsigned fc) const
     for (i = 0; i < ENTRIES; i++)
     {
         // The loop will leave unchanged any MS font name not fuzzy-matched.
-        if (font.find(fuzzyLookup[i][0], 0, FALSE) != -1)
+        if (font.find(fuzzyLookup[i][0], 0, false) != -1)
         {
             font = fuzzyLookup[i][1];
             break;
@@ -523,7 +525,7 @@ QString KWordTextHandler::getFont(unsigned fc) const
     }
 
 #ifdef FONT_DEBUG
-    kdDebug(30513) << "    FUZZY-FONT: " << font << endl;
+    kDebug(30513) <<"    FUZZY-FONT:" << font;
 #endif
 
     // Use Qt to look up our canonical equivalent of the font name.
@@ -531,7 +533,7 @@ QString KWordTextHandler::getFont(unsigned fc) const
     QFontInfo info( xFont );
 
 #ifdef FONT_DEBUG
-    kdDebug(30513) << "    QT-FONT: " << info.family() << endl;
+    kDebug(30513) <<"    QT-FONT:" << info.family();
 #endif
 
     return info.family();
@@ -542,7 +544,7 @@ void KWordTextHandler::writeOutParagraph( const QString& styleName, const QStrin
     if ( m_framesetElement.isNull() )
     {
         if ( !text.isEmpty() ) // vertically merged table cells are ignored, and have empty text -> no warning on those
-            kdWarning(30513) << "KWordTextHandler: no frameset element to write to! text=" << text << endl;
+            kWarning(30513) << "KWordTextHandler: no frameset element to write to! text=" << text;
         return;
     }
     QDomElement paragraphElementOut=mainDocument().createElement("PARAGRAPH");
@@ -580,7 +582,7 @@ void KWordTextHandler::writeLayout( QDomElement& parentElement, const wvWare::Pa
     flowElement.setAttribute( "align", alignment );
     parentElement.appendChild( flowElement );
 
-    //kdDebug(30513) << k_funcinfo << " dxaLeft1=" << pap.dxaLeft1 << " dxaLeft=" << pap.dxaLeft << " dxaRight=" << pap.dxaRight << " dyaBefore=" << pap.dyaBefore << " dyaAfter=" << pap.dyaAfter << " lspd=" << pap.lspd.dyaLine << "/" << pap.lspd.fMultLinespace << endl;
+    //kDebug(30513) <<" dxaLeft1=" << pap.dxaLeft1 <<" dxaLeft=" << pap.dxaLeft <<" dxaRight=" << pap.dxaRight <<" dyaBefore=" << pap.dyaBefore <<" dyaAfter=" << pap.dyaAfter <<" lspd=" << pap.lspd.dyaLine <<"/" << pap.lspd.fMultLinespace;
 
     if ( pap.dxaLeft1 || pap.dxaLeft || pap.dxaRight )
     {
@@ -654,7 +656,7 @@ void KWordTextHandler::writeLayout( QDomElement& parentElement, const wvWare::Pa
             const wvWare::Word97::TabDescriptor &td = pap.rgdxaTab[i];
             QDomElement tabElement = mainDocument().createElement( "TABULATOR" );
             tabElement.setAttribute( "ptpos", (double)td.dxaTab / 20.0 );
-            //kdDebug(30513) << "ptpos=" << (double)td.dxaTab / 20.0 << endl;
+            //kDebug(30513) <<"ptpos=" << (double)td.dxaTab / 20.0;
             // Wow, lucky here. The type enum matches. Only, MSWord has 4=bar,
             // which kword doesn't support. We map it to 0 with a clever '%4' :)
             tabElement.setAttribute( "type", td.tbd.jc % 4 );
@@ -717,14 +719,14 @@ void KWordTextHandler::writeCounter( QDomElement& parentElement, const wvWare::P
                 counterElement.setAttribute( "type", 11 ); // Box. We have no triangle.
             } else {
                 // Map all other bullets to a "custom bullet" in kword.
-                kdDebug(30513) << "custom bullet, code=" << QString::number(code,16) << endl;
+                kDebug(30513) <<"custom bullet, code=" << QString::number(code,16);
                 counterElement.setAttribute( "type", 6 ); // custom
                 counterElement.setAttribute( "bullet", code );
                 QString paragFont = getFont( style->chp().ftcAscii );
                 counterElement.setAttribute( "bulletfont", paragFont );
             }
         } else
-            kdWarning(30513) << "Bullet with more than one character, not supported" << endl;
+            kWarning(30513) << "Bullet with more than one character, not supported";
     }
     else
     {
@@ -739,7 +741,7 @@ void KWordTextHandler::writeCounter( QDomElement& parentElement, const wvWare::P
         {
             depth = style->sti() - 1;
         }
-        kdDebug(30513) << "  ilfo=" << pap.ilfo << " ilvl=" << pap.ilvl << " sti=" << style->sti() << " depth=" << depth << " numberingType=" << numberingType << endl;
+        kDebug(30513) <<"  ilfo=" << pap.ilfo <<" ilvl=" << pap.ilvl <<" sti=" << style->sti() <<" depth=" << depth <<" numberingType=" << numberingType;
         counterElement.setAttribute( "depth", depth );
 
         // Now we need to parse the text, to try and convert msword's powerful list template
@@ -753,19 +755,19 @@ void KWordTextHandler::writeCounter( QDomElement& parentElement, const wvWare::P
         for ( int i = 0 ; i < text.length() ; ++i )
         {
             short ch = text[i].unicode();
-            //kdDebug(30513) << i << ":" << ch << endl;
+            //kDebug(30513) << i <<":" << ch;
             if ( ch < 10 ) { // List level place holder
                 if ( ch == pap.ilvl ) {
                     if ( depthFound )
-                        kdWarning(30513) << "ilvl " << pap.ilvl << " found twice in listInfo text..." << endl;
+                        kWarning(30513) << "ilvl " << pap.ilvl << " found twice in listInfo text...";
                     else
                         depthFound = true;
-                    suffix = QString::null;
+                    suffix.clear();
                 } else {
                     Q_ASSERT( ch < pap.ilvl ); // Can't see how level 1 would have a <0> in it...
                     if ( ch < pap.ilvl )
                         ++displayLevels; // we found a 'parent level', to be displayed
-                    prefix = QString::null; // get rid of previous prefixes
+                    prefix.clear(); // get rid of previous prefixes
                 }
             } else { // Normal character
                 if ( depthFound )
@@ -781,8 +783,8 @@ void KWordTextHandler::writeCounter( QDomElement& parentElement, const wvWare::P
             // so it will indeed look like that).
             // The question is whether the '.' is the suffix of the parent level already..
             if ( depth > 0 && !prefix.isEmpty() && m_listSuffixes[ depth - 1 ] == prefix )  {
-                prefix = QString::null; // it's already the parent's suffix -> remove it
-                kdDebug(30513) << "depth=" << depth << " parent suffix is " << prefix << " -> clearing" << endl;
+                prefix.clear(); // it's already the parent's suffix -> remove it
+                kDebug(30513) <<"depth=" << depth <<" parent suffix is" << prefix <<" -> clearing";
             }
         }
         if ( isHeading )
@@ -792,17 +794,17 @@ void KWordTextHandler::writeCounter( QDomElement& parentElement, const wvWare::P
             // Word6 models "1." as nfc=5
             if ( nfc == 5 && suffix.isEmpty() )
                 suffix = ".";
-            kdDebug(30513) << " prefix=" << prefix << " suffix=" << suffix << endl;
+            kDebug(30513) <<" prefix=" << prefix <<" suffix=" << suffix;
             counterElement.setAttribute( "type", Conversion::numberFormatCode( nfc ) );
             counterElement.setAttribute( "lefttext", prefix );
             counterElement.setAttribute( "righttext", suffix );
             counterElement.setAttribute( "display-levels", displayLevels );
-            kdDebug(30513) << "storing suffix " << suffix << " for depth " << depth << endl;
+            kDebug(30513) <<"storing suffix" << suffix <<" for depth" << depth;
             m_listSuffixes[ depth ] = suffix;
         }
         else
         {
-            kdWarning(30513) << "Not supported: counter text without the depth in it:" << Conversion::string(text).string() << endl;
+            kWarning(30513) << "Not supported: counter text without the depth in it:" << Conversion::string(text).string();
         }
 
         if ( listInfo->startAtOverridden() ||
@@ -827,7 +829,7 @@ void KWordTextHandler::setFrameSetElement( const QDomElement& frameset )
 {
     m_framesetElement = frameset;
     for ( uint i = 0 ; i < 9 ; ++i )
-        m_listSuffixes[i] = QString::null;
+        m_listSuffixes[i].clear();
 }
 
 QDomDocument KWordTextHandler::mainDocument() const
