@@ -30,11 +30,16 @@
    License version 2.
 */
 
-#include <qmap.h>
-#include <qiodevice.h>
-#include <qbuffer.h>
-#include <qtextstream.h>
+#include <QMap>
+#include <QIODevice>
+#include <QBuffer>
+#include <QTextStream>
 #include <qdom.h>
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <QByteArray>
+#include <Q3MemArray>
+#include <QBuffer>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -180,7 +185,7 @@ QString OOWriterWorker::escapeOOSpan(const QString& strText) const
         case 30:
         case 31:
             {
-                kdWarning(30518) << "Not allowed XML character: " << ch.unicode() << endl;
+                kWarning(30518) << "Not allowed XML character: " << ch.unicode();
                 strReturn += '?';
                 break;
             }
@@ -212,14 +217,14 @@ QString OOWriterWorker::escapeOOSpan(const QString& strText) const
 
 bool OOWriterWorker::doOpenFile(const QString& filenameOut, const QString& )
 {
-    kdDebug(30518) << "Opening file: " << filenameOut
+    kDebug(30518) <<"Opening file:" << filenameOut
         << " (in OOWriterWorker::doOpenFile)" << endl;
 
     m_zip=new KZip(filenameOut); // How to check failure?
 
-    if (!m_zip->open(IO_WriteOnly))
+    if (!m_zip->open(QIODevice::WriteOnly))
     {
-        kdError(30518) << "Could not open ZIP file for writing! Aborting!" << endl;
+        kError(30518) << "Could not open ZIP file for writing! Aborting!" << endl;
         delete m_zip;
         m_zip=NULL;
         return false;
@@ -228,13 +233,13 @@ bool OOWriterWorker::doOpenFile(const QString& filenameOut, const QString& )
     m_zip->setCompression( KZip::NoCompression );
     m_zip->setExtraField( KZip::NoExtraField );
 
-    const QCString appId( "application/vnd.sun.xml.writer" );
+    const QByteArray appId( "application/vnd.sun.xml.writer" );
 
-    m_zip->writeFile( "mimetype", QString::null, QString::null, appId.length(), appId.data() );
+    m_zip->writeFile( "mimetype", QString(), QString(), appId.data(), appId.length() );
 
     m_zip->setCompression( KZip::DeflateCompression );
 
-    m_streamOut=new QTextStream(m_contentBody, IO_WriteOnly);
+    m_streamOut=new QTextStream(m_contentBody, QIODevice::WriteOnly);
 
     m_streamOut->setEncoding( QTextStream::UnicodeUTF8 );
 
@@ -246,14 +251,14 @@ bool OOWriterWorker::zipPrepareWriting(const QString& name)
     if (!m_zip)
         return false;
     m_size=0;
-    return m_zip->prepareWriting(name, QString::null, QString::null, 0);
+    return m_zip->prepareWriting(name, QString(), QString(), 0);
 }
 
 bool OOWriterWorker::zipDoneWriting(void)
 {
     if (!m_zip)
         return false;
-    return m_zip->doneWriting(m_size);
+    return m_zip->finishWriting(m_size);
 }
 
 bool OOWriterWorker::zipWriteData(const char* str)
@@ -274,15 +279,6 @@ bool OOWriterWorker::zipWriteData(const QByteArray& array)
     return m_zip->writeData(array.data(),size);
 }
 
-bool OOWriterWorker::zipWriteData(const QCString& cstr)
-{
-    if (!m_zip)
-        return false;
-    const uint size=cstr.length();
-    m_size+=size;
-    return m_zip->writeData(cstr.data(),size);
-}
-
 bool OOWriterWorker::zipWriteData(const QString& str)
 {
     return zipWriteData(str.utf8());
@@ -358,8 +354,8 @@ void OOWriterWorker::writeStartOfFile(const QString& type)
 void OOWriterWorker::writeFontDeclaration(void)
 {
     zipWriteData( " <office:font-decls>\n");
-	QMap<QString,QString>::ConstIterator end(m_fontNames.end());
-    for (QMap<QString,QString>::ConstIterator it=m_fontNames.begin(); it!=end; ++it)
+	QMap<QString,QString>::ConstIterator end(m_fontNames.constEnd());
+    for (QMap<QString,QString>::ConstIterator it=m_fontNames.constBegin(); it!=end; ++it)
     {
         const bool space=(it.key().find(' ')>=0); // Does the font has at least a space in its name
         const QString fontName(escapeOOText(it.key()));
@@ -474,7 +470,7 @@ void OOWriterWorker::writeContentXml(void)
 
     zipWriteData(" <office:automatic-styles>\n");
     zipWriteData(m_contentAutomaticStyles);
-    m_contentAutomaticStyles = QString::null; // Release memory
+    m_contentAutomaticStyles.clear(); // Release memory
     
     zipWriteData(" </office:automatic-styles>\n");
 
@@ -499,7 +495,7 @@ void OOWriterWorker::writeMetaXml(void)
 
     // Tell who we are in case that we have a bug in our filter output!
     zipWriteData("  <meta:generator>KWord's OOWriter Export Filter");
-    zipWriteData(QString("$Revision: 515673 $").mid(10).remove('$')); // has a leading and a trailing space.
+    zipWriteData(QString("$Revision: 911800 $").mid(10).remove('$')); // has a leading and a trailing space.
 
     zipWriteData("</meta:generator>\n");
 
@@ -565,7 +561,7 @@ void OOWriterWorker::writeMetaXml(void)
 
 bool OOWriterWorker::doCloseFile(void)
 {
-    kdDebug(30518)<< "OOWriterWorker::doCloseFile" << endl;
+    kDebug(30518)<<"OOWriterWorker::doCloseFile";
     if (m_zip)
     {
         writeContentXml();
@@ -581,7 +577,7 @@ bool OOWriterWorker::doCloseFile(void)
 
 bool OOWriterWorker::doOpenDocument(void)
 {
-    kdDebug(30518)<< "OOWriterWorker::doOpenDocument" << endl;
+    kDebug(30518)<<"OOWriterWorker::doOpenDocument";
 
     *m_streamOut << " <office:body>\n";
 
@@ -596,27 +592,27 @@ bool OOWriterWorker::doCloseDocument(void)
 
 bool OOWriterWorker::doOpenBody(void)
 {
-    QValueList<FrameAnchor>::Iterator it;
+    Q3ValueList<FrameAnchor>::Iterator it;
 
     // We have to process all non-inline pictures
-    kdDebug(30518) << "=== Processing non-inlined pictures ===" << endl;
+    kDebug(30518) <<"=== Processing non-inlined pictures ===";
     for ( it = m_nonInlinedPictureAnchors.begin(); it != m_nonInlinedPictureAnchors.end(); ++it )
     {
         *m_streamOut << "  ";
         makePicture( *it, AnchorNonInlined );
         *m_streamOut << "\n";
     }
-    kdDebug(30518) << "=== Non-inlined pictures processed ===" << endl;
+    kDebug(30518) <<"=== Non-inlined pictures processed ===";
 
     // We have to process all non-inline tables
-    kdDebug(30518) << "=== Processing non-inlined tables ===" << endl;
+    kDebug(30518) <<"=== Processing non-inlined tables ===";
     for ( it = m_nonInlinedTableAnchors.begin(); it != m_nonInlinedTableAnchors.end(); ++it )
     {
         *m_streamOut << "  ";
         makeTable( *it, AnchorNonInlined );
         *m_streamOut << "\n";
     }
-    kdDebug(30518) << "=== Non-inlined tables processed ===" << endl;
+    kDebug(30518) <<"=== Non-inlined tables processed ===";
 
     return true;
 }
@@ -639,7 +635,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         key += fontName;
     }
 
-    key += ",";
+    key += ',';
 
     if (force || (formatOrigin.italic!=formatData.italic))
     {
@@ -658,7 +654,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         strElement+="\" ";
     }
 
-    key += ",";
+    key += ',';
 
     if (force || ((formatOrigin.weight>=75)!=(formatData.weight>=75)))
     {
@@ -676,7 +672,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         strElement+="\" ";
     }
 
-    key += ",";
+    key += ',';
 
     if (force || (formatOrigin.fontSize!=formatData.fontSize))
     {
@@ -690,7 +686,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         }
     }
 
-    key += ",";
+    key += ',';
 
     if (force || (formatOrigin.fgColor!=formatData.fgColor))
     {
@@ -703,7 +699,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         }
     }
 
-    key += ",";
+    key += ',';
 
     if (force || (formatOrigin.bgColor!=formatData.bgColor))
     {
@@ -759,13 +755,13 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
                 else
                 {
                     strElement += "single";
-                    key += "1";
+                    key += '1';
                 }
             }
             else if ( underlineValue == "double" )
             {
                 strElement += "double";
-                key += "2";
+                key += '2';
             }
             else if ( underlineValue == "single-bold" )
             {
@@ -780,7 +776,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
             else
             {
                 strElement += "single";
-                key += "?";
+                key += '?';
             }
         }
         else
@@ -814,17 +810,17 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         if ( ( formatData.strikeoutType == "single" ) || ( formatData.strikeoutType == "1" ) )
         {
             strElement+="single-line";
-            key += "1";
+            key += '1';
         }
         else if ( formatData.strikeoutType == "double" )
         {
             strElement+="double-line";
-            key += "2";
+            key += '2';
         }
         else if ( formatData.strikeoutType == "single-bold" )
         {
             strElement+="thick";
-            key += "T";
+            key += 'T';
         }
         else
         {
@@ -868,7 +864,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
 
             if ( res >= 0 )
             {
-                kdDebug(30518) << "Language: " << lang << " => " << lang.left( res ) << " - " << lang.mid( res + 1 ) << endl;
+                kDebug(30518) <<"Language:" << lang <<" =>" << lang.left( res ) <<" -" << lang.mid( res + 1 );
                 strElement += "fo:language=\"";
                 strElement += lang.left( res );
                 strElement += "\" ";
@@ -878,7 +874,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
             }
             else
             {
-                kdDebug(30518) << "Language without country: " << lang << endl;
+                kDebug(30518) <<"Language without country:" << lang;
                 strElement += "fo:language=\"";
                 strElement += lang;
                 strElement += "\" ";
@@ -888,7 +884,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         }
     }
 
-    key += ",";
+    key += ',';
 
     if ( force || ( formatOrigin.fontAttribute != formatData.fontAttribute ) )
     {
@@ -917,7 +913,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         }
     }
 
-    key += ",";
+    key += ',';
 
     if ( force || ( formatOrigin.verticalAlignment != formatData.verticalAlignment ) )
     {
@@ -936,7 +932,7 @@ QString OOWriterWorker::textFormatToStyle(const TextFormatting& formatOrigin,
         // ### TODO: how to reset it? "0pt" ?
     }
 
-    return strElement.stripWhiteSpace(); // Remove especially trailing spaces
+    return strElement.trimmed(); // Remove especially trailing spaces
 }
 
 #define ALLOW_TABLE
@@ -949,7 +945,7 @@ QString OOWriterWorker::cellToProperties( const TableCell& cell, QString& key) c
 
     key += "!L"; // left border
     key += frame.lColor.name();
-    key += ",";
+    key += ',';
     key += QString::number( frame.lWidth );
     properties += " fo:border-left=\"";
     if ( frame.lColor.isValid() && frame.lWidth > 0.0 )
@@ -967,7 +963,7 @@ QString OOWriterWorker::cellToProperties( const TableCell& cell, QString& key) c
 
     key += "!R"; // right border
     key += frame.rColor.name();
-    key += ",";
+    key += ',';
     key += QString::number( frame.rWidth );
     properties += " fo:border-right=\"";
     if ( frame.rColor.isValid() && frame.rWidth > 0.0 )
@@ -985,7 +981,7 @@ QString OOWriterWorker::cellToProperties( const TableCell& cell, QString& key) c
 
     key += "!T"; // top border
     key += frame.tColor.name();
-    key += ",";
+    key += ',';
     key += QString::number( frame.tWidth );
     properties += " fo:border-top=\"";
     if ( frame.tColor.isValid() && frame.tWidth > 0.0 )
@@ -1003,7 +999,7 @@ QString OOWriterWorker::cellToProperties( const TableCell& cell, QString& key) c
 
     key += "!B"; // bottom border
     key += frame.bColor.name();
-    key += ",";
+    key += ',';
     key += QString::number( frame.bWidth );
     properties += " fo:border-bottom=\"";
     if ( frame.bColor.isValid() && frame.bWidth > 0.0 )
@@ -1021,7 +1017,7 @@ QString OOWriterWorker::cellToProperties( const TableCell& cell, QString& key) c
 
     return properties;
 #else
-    return QString::null;
+    return QString();
 #endif
 }
 
@@ -1040,7 +1036,7 @@ bool OOWriterWorker::makeTableRows( const QString& tableName, const Table& table
 
     QMap<QString,QString> mapCellStyleKeys;
 
-    for ( QValueList<TableCell>::ConstIterator itCell ( table.cellList.begin() );
+    for ( Q3ValueList<TableCell>::ConstIterator itCell ( table.cellList.begin() );
         itCell != table.cellList.end(); ++itCell)
     {
         if ( rowCurrent != (*itCell).row )
@@ -1054,12 +1050,12 @@ bool OOWriterWorker::makeTableRows( const QString& tableName, const Table& table
         const QString props ( cellToProperties( (*itCell), key ) );
 
         QString automaticCellStyle;
-        QMap<QString,QString>::ConstIterator it ( mapCellStyleKeys.find( key ) );
-        if ( it == mapCellStyleKeys.end() )
+        QMap<QString,QString>::ConstIterator it ( mapCellStyleKeys.constFind( key ) );
+        if ( it == mapCellStyleKeys.constEnd() )
         {
             automaticCellStyle = makeAutomaticStyleName( tableName + ".Cell", cellNumber );
             mapCellStyleKeys [ key ] = automaticCellStyle;
-            kdDebug(30518) << "Creating automatic cell style: " << automaticCellStyle  << " key: " << key << endl;
+            kDebug(30518) <<"Creating automatic cell style:" << automaticCellStyle  <<" key:" << key;
             m_contentAutomaticStyles += "  <style:style";
             m_contentAutomaticStyles += " style:name=\"" + escapeOOText( automaticCellStyle ) + "\"";
             m_contentAutomaticStyles += " style:family=\"table-cell\"";
@@ -1072,7 +1068,7 @@ bool OOWriterWorker::makeTableRows( const QString& tableName, const Table& table
         else
         {
             automaticCellStyle = it.data();
-            kdDebug(30518) << "Using automatic cell style: " << automaticCellStyle  << " key: " << key << endl;
+            kDebug(30518) <<"Using automatic cell style:" << automaticCellStyle  <<" key:" << key;
         }
 
         *m_streamOut << "<table:table-cell table:value-type=\"string\" table:style-name=\""
@@ -1111,17 +1107,17 @@ bool OOWriterWorker::makeTableRows( const QString& tableName, const Table& table
 }
 
 #ifdef ALLOW_TABLE
-static uint getColumnWidths( const Table& table, QMemArray<double>& widthArray, int firstRowNumber )
+static uint getColumnWidths( const Table& table, Q3MemArray<double>& widthArray, int firstRowNumber )
 {
     bool uniqueColumns = true; // We have not found any horizontally spanned cells yet.
     uint currentColumn = 0;
     int tryingRow = firstRowNumber; // We are trying the first row
-    QValueList<TableCell>::ConstIterator itCell;
+    Q3ValueList<TableCell>::ConstIterator itCell;
 
     for ( itCell = table.cellList.begin();
         itCell != table.cellList.end(); ++itCell )
     {
-        kdDebug(30518) << "Column: " << (*itCell).col << " (Row: " << (*itCell).row << ")" << endl;
+        kDebug(30518) <<"Column:" << (*itCell).col <<" (Row:" << (*itCell).row <<")";
 
         if ( (*itCell).row != tryingRow )
         {
@@ -1150,7 +1146,7 @@ static uint getColumnWidths( const Table& table, QMemArray<double>& widthArray,
         const double width = ( (*itCell).frame.right - (*itCell).frame.left );
 
         if ( currentColumn >= widthArray.size() )
-            widthArray.resize( currentColumn + 4, QGArray::SpeedOptim);
+            widthArray.resize( currentColumn + 4, Q3GArray::SpeedOptim);
 
         widthArray.at( currentColumn ) = width;
         ++currentColumn;
@@ -1165,17 +1161,17 @@ static uint getColumnWidths( const Table& table, QMemArray<double>& widthArray,
 #endif
 
 #ifdef ALLOW_TABLE
-static uint getFirstRowColumnWidths( const Table& table, QMemArray<double>& widthArray, int firstRowNumber )
+static uint getFirstRowColumnWidths( const Table& table, Q3MemArray<double>& widthArray, int firstRowNumber )
 // Get the column widths only by the first row.
 // This is used when all table rows have horizontally spanned cells.
 {
     uint currentColumn = 0;
-    QValueList<TableCell>::ConstIterator itCell;
+    Q3ValueList<TableCell>::ConstIterator itCell;
 
     for ( itCell = table.cellList.begin();
         itCell != table.cellList.end(); ++itCell )
     {
-        kdDebug(30518) << "Column: " << (*itCell).col << " (Row: " << (*itCell).row << ")" << endl;
+        kDebug(30518) <<"Column:" << (*itCell).col <<" (Row:" << (*itCell).row <<")";
         if ( (*itCell).row != firstRowNumber )
             break; // We have finished the first row
 
@@ -1187,7 +1183,7 @@ static uint getFirstRowColumnWidths( const Table& table, QMemArray<double>& widt
         const double width = ( (*itCell).frame.right - (*itCell).frame.left ) / cols;
 
         if ( currentColumn + cols > widthArray.size() )
-            widthArray.resize( currentColumn + 4, QGArray::SpeedOptim);
+            widthArray.resize( currentColumn + 4, Q3GArray::SpeedOptim);
 
         for ( int i = 0; i < cols; ++i )
         {
@@ -1206,41 +1202,41 @@ bool OOWriterWorker::makeTable( const FrameAnchor& anchor, const AnchorType anch
     // Be careful that while being similar the following 5 strings have different purposes
     const QString automaticTableStyle ( makeAutomaticStyleName( "Table", m_tableNumber ) ); // It also increases m_tableNumber
     const QString tableName( QString( "Table" ) + QString::number( m_tableNumber ) ); // m_tableNumber was already increased
-    const QString translatedName( i18n( "Object name", "Table %1").arg( m_tableNumber ) );
+    const QString translatedName( i18nc( "Object name", "Table %1", m_tableNumber ) );
     const QString automaticFrameStyle ( makeAutomaticStyleName( "TableFrame", m_textBoxNumber ) ); // It also increases m_textBoxNumber
-    const QString translatedFrameName( i18n( "Object name", "Table Frame %1").arg( m_textBoxNumber ) );
+    const QString translatedFrameName( i18nc( "Object name", "Table Frame %1", m_textBoxNumber ) );
 
-    kdDebug(30518) << "Processing table " << anchor.key.toString() << " => " << tableName << endl;
+    kDebug(30518) <<"Processing table" << anchor.key.toString() <<" =>" << tableName;
 
-    const QValueList<TableCell>::ConstIterator firstCell ( anchor.table.cellList.begin() );
+    const Q3ValueList<TableCell>::ConstIterator firstCell ( anchor.table.cellList.begin() );
 
     if ( firstCell == anchor.table.cellList.end() )
     {
-        kdError(30518) << "Table has not any cell!" << endl;
+        kError(30518) << "Table has not any cell!" << endl;
         return false;
     }
 
     const int firstRowNumber = (*firstCell).row;
-    kdDebug(30518) << "First row: " << firstRowNumber << endl;
+    kDebug(30518) <<"First row:" << firstRowNumber;
 
-    QMemArray<double> widthArray(4);
+    Q3MemArray<double> widthArray(4);
 
     uint numberColumns = getColumnWidths( anchor.table, widthArray, firstRowNumber );
 
     if ( numberColumns <= 0 )
     {
-        kdDebug(30518) << "Could not get correct column widths, so approximating" << endl;
+        kDebug(30518) <<"Could not get correct column widths, so approximating";
         // There was a problem, the width array cannot be trusted, so try to do a column width array with the first row
         numberColumns = getFirstRowColumnWidths( anchor.table, widthArray, firstRowNumber );
         if ( numberColumns <= 0 )
         {
             // Still not right? Then it is an error!
-            kdError(30518) << "Cannot get column widths of table " << anchor.key.toString() << endl;
+            kError(30518) << "Cannot get column widths of table " << anchor.key.toString() << endl;
             return false;
         }
     }
 
-    kdDebug(30518) << "Number of columns: " << numberColumns << endl;
+    kDebug(30518) <<"Number of columns:" << numberColumns;
 
 
     double tableWidth = 0.0; // total width of table
@@ -1249,7 +1245,7 @@ bool OOWriterWorker::makeTable( const FrameAnchor& anchor, const AnchorType anch
     {
         tableWidth += widthArray.at( i );
     }
-    kdDebug(30518) << "Table width: " << tableWidth << endl;
+    kDebug(30518) <<"Table width:" << tableWidth;
 
     // An inlined table, is an "as-char" text-box
     *m_streamOut << "<draw:text-box";
@@ -1277,7 +1273,7 @@ bool OOWriterWorker::makeTable( const FrameAnchor& anchor, const AnchorType anch
 
     // Now we have enough information to generate the style for the table and its frame
 
-    kdDebug(30518) << "Creating automatic frame style: " << automaticFrameStyle /* << " key: " << styleKey */ << endl;
+    kDebug(30518) <<"Creating automatic frame style:" << automaticFrameStyle /* <<" key:" << styleKey */;
     m_contentAutomaticStyles += "  <style:style"; // for frame
     m_contentAutomaticStyles += " style:name=\"" + escapeOOText( automaticFrameStyle ) + "\"";
     m_contentAutomaticStyles += " style:family=\"graphics\"";
@@ -1293,7 +1289,7 @@ bool OOWriterWorker::makeTable( const FrameAnchor& anchor, const AnchorType anch
     m_contentAutomaticStyles += "/>\n";
     m_contentAutomaticStyles += "  </style:style>\n";
 
-    kdDebug(30518) << "Creating automatic table style: " << automaticTableStyle /* << " key: " << styleKey */ << endl;
+    kDebug(30518) <<"Creating automatic table style:" << automaticTableStyle /* <<" key:" << styleKey */;
     m_contentAutomaticStyles += "  <style:style"; // for table
     m_contentAutomaticStyles += " style:name=\"" + escapeOOText( automaticTableStyle ) + "\"";
     m_contentAutomaticStyles += " style:family=\"table\"";
@@ -1303,14 +1299,14 @@ bool OOWriterWorker::makeTable( const FrameAnchor& anchor, const AnchorType anch
     m_contentAutomaticStyles += "/>\n";
     m_contentAutomaticStyles += "  </style:style>\n";
 
-    QValueList<TableCell>::ConstIterator itCell;
+    Q3ValueList<TableCell>::ConstIterator itCell;
 
     ulong columnNumber = 0L;
 
     for ( i=0; i < numberColumns; ++i )
     {
         const QString automaticColumnStyle ( makeAutomaticStyleName( tableName + ".Column", columnNumber ) );
-        kdDebug(30518) << "Creating automatic column style: " << automaticColumnStyle /* << " key: " << styleKey */ << endl;
+        kDebug(30518) <<"Creating automatic column style:" << automaticColumnStyle /* <<" key:" << styleKey */;
 
         m_contentAutomaticStyles += "  <style:style";
         m_contentAutomaticStyles += " style:name=\"" + escapeOOText( automaticColumnStyle ) + "\"";
@@ -1341,14 +1337,14 @@ bool OOWriterWorker::makeTable( const FrameAnchor& anchor, const AnchorType anch
 
 bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType anchorType )
 {
-    kdDebug(30518) << "New picture: " << anchor.picture.koStoreName
+    kDebug(30518) <<"New picture:" << anchor.picture.koStoreName
         << " , " << anchor.picture.key.toString() << endl;
 
     const QString koStoreName(anchor.picture.koStoreName);
 
     QByteArray image;
 
-    QString strExtension(koStoreName.lower());
+    QString strExtension(koStoreName.toLower());
     const int result=koStoreName.findRev(".");
     if (result>=0)
     {
@@ -1385,11 +1381,11 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
 
     if (!isImageLoaded)
     {
-        kdWarning(30518) << "Unable to load picture: " << koStoreName << endl;
+        kWarning(30518) << "Unable to load picture: " << koStoreName;
         return true;
     }
 
-    kdDebug(30518) << "Picture loaded: " << koStoreName << endl;
+    kDebug(30518) <<"Picture loaded:" << koStoreName;
 
     double height = 0.0;
     double width = 0.0;
@@ -1397,9 +1393,10 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
     if ( anchorType == AnchorTextImage )
     {
         // Text image have no frameset, so the only size information is in the picture itself.
-        QBuffer buffer( image.copy() ); // Be more safe than sorry and do not allow shallow copy
+        QByteArray tmp(image);
+		QBuffer buffer( &tmp ); // Be more safe than sorry and do not allow shallow copy
         KoPicture pic;
-        buffer.open( IO_ReadOnly );
+        buffer.open( QIODevice::ReadOnly );
         if ( pic.load( &buffer, strExtension ) )
         {
             const QSize size ( pic.getOriginalSize() );
@@ -1408,7 +1405,7 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
         }
         else
         {
-            kdWarning(30518) << "Could not load KoPicture: " << koStoreName << endl;
+            kWarning(30518) << "Could not load KoPicture: " << koStoreName;
         }
         buffer.close();
     }
@@ -1421,12 +1418,12 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
 
     if ( height < 1.0 )
     {
-        kdWarning(30518) << "Silly height for " << koStoreName << " : "  << height << endl;
+        kWarning(30518) << "Silly height for " << koStoreName << " : "  << height;
         height = 72.0;
     }
     if ( width < 1.0 )
     {
-        kdWarning(30518) << "Silly width for " << koStoreName << " : "  << width << endl;
+        kWarning(30518) << "Silly width for " << koStoreName << " : "  << width;
         width = 72.0;
     }
 
@@ -1441,7 +1438,7 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
     ooName += '.';
     ooName += strExtension;
 
-    kdDebug(30518) << "Picture " << koStoreName << " => " << ooName << endl;
+    kDebug(30518) <<"Picture" << koStoreName <<" =>" << ooName;
 
     // TODO: we are only using the filename, not the rest of the key
     // TODO:  (bad if there are two images of the same name, but of a different key)
@@ -1465,7 +1462,7 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
     {
 #if 0
         // ### FIXME Why is the following line not working (at least with KDE 3.1)? (It makes unzip having problems with meta.xml)
-        m_zip->writeFile(ooName,QString::null, QString::null, image.size(), image.data());
+        m_zip->writeFile(ooName, QString(), QString(), image.size(), image.data());
 #else
         zipPrepareWriting(ooName);
         zipWriteData( image );
@@ -1495,15 +1492,15 @@ void OOWriterWorker::processNormalText ( const QString &paraText,
         QString styleKey;
         const QString props ( textFormatToStyle(formatLayout,formatData.text,false,styleKey) );
 
-        QMap<QString,QString>::ConstIterator it ( m_mapTextStyleKeys.find(styleKey) );
-        kdDebug(30518) << "Searching text key: " << styleKey << endl;
+        QMap<QString,QString>::ConstIterator it ( m_mapTextStyleKeys.constFind(styleKey) );
+        kDebug(30518) <<"Searching text key:" << styleKey;
 
         QString automaticStyle;
-        if (it==m_mapTextStyleKeys.end())
+        if (it==m_mapTextStyleKeys.constEnd())
         {
             // We have not any match, so we need a new automatic text style
             automaticStyle=makeAutomaticStyleName("T", m_automaticTextStyleNumber);
-            kdDebug(30518) << "Creating automatic text style: " << automaticStyle << " key: " << styleKey << endl;
+            kDebug(30518) <<"Creating automatic text style:" << automaticStyle <<" key:" << styleKey;
             m_mapTextStyleKeys[styleKey]=automaticStyle;
 
             m_contentAutomaticStyles += "  <style:style";
@@ -1519,7 +1516,7 @@ void OOWriterWorker::processNormalText ( const QString &paraText,
         {
             // We have a match, so use the already defined automatic text style
             automaticStyle=it.data();
-            kdDebug(30518) << "Using automatic text style: " << automaticStyle << " key: " << styleKey << endl;
+            kDebug(30518) <<"Using automatic text style:" << automaticStyle <<" key:" << styleKey;
         }
 
         *m_streamOut << " text:style-name=\"" << escapeOOText(automaticStyle) << "\" ";
@@ -1531,7 +1528,7 @@ void OOWriterWorker::processNormalText ( const QString &paraText,
 void OOWriterWorker::processFootnote( const VariableData& variable )
 {
     // Footnote
-    const QValueList<ParaData> *paraList = variable.getFootnotePara();
+    const Q3ValueList<ParaData> *paraList = variable.getFootnotePara();
     if( paraList )
     {
         const QString value ( variable.getFootnoteValue() );
@@ -1585,7 +1582,7 @@ void OOWriterWorker::processNote( const VariableData& variable )
 
     // We try to use the document author's name as annotation author
     if ( m_docInfo.fullName.isEmpty() )
-        *m_streamOut << escapeOOText( i18n( "Pseudo-author for annotations", "KWord 1.3" ) );
+        *m_streamOut << escapeOOText( i18nc( "Pseudo-author for annotations", "KWord 1.3" ) );
     else
         *m_streamOut << escapeOOText( m_docInfo.fullName );
 
@@ -1666,7 +1663,7 @@ void OOWriterWorker::processAnchor ( const QString&,
     }
     else
     {
-        kdWarning(30518) << "Unsupported anchor type: "
+        kWarning(30518) << "Unsupported anchor type: "
             << formatData.frameAnchor.type << endl;
     }
 }
@@ -1675,7 +1672,7 @@ void OOWriterWorker::processTextImage ( const QString&,
     const TextFormatting& /*formatLayout*/,
     const FormatData& formatData)
 {
-    kdDebug(30518) << "Text Image: " << formatData.frameAnchor.key.toString() << endl;
+    kDebug(30518) <<"Text Image:" << formatData.frameAnchor.key.toString();
     makePicture( formatData.frameAnchor, AnchorTextImage );
 }
 
@@ -1770,7 +1767,7 @@ QString OOWriterWorker::layoutToParagraphStyle(const LayoutData& layoutOrigin,
         }
         else
         {
-            kdWarning(30518) << "Unknown alignment: " << layout.alignment << endl;
+            kWarning(30518) << "Unknown alignment: " << layout.alignment;
         }
     }
 
@@ -1865,7 +1862,7 @@ QString OOWriterWorker::layoutToParagraphStyle(const LayoutData& layoutOrigin,
                 props += mult;
                 props += "%\" ";
                 styleKey += mult;
-                styleKey += "%";
+                styleKey += '%';
                 break;
             }
         case LayoutData::LS_FIXED:
@@ -1892,7 +1889,7 @@ QString OOWriterWorker::layoutToParagraphStyle(const LayoutData& layoutOrigin,
             }
         default:
             {
-                kdWarning(30518) << "Unsupported lineSpacingType: " << layout.lineSpacingType << " (Ignoring!)" << endl;
+                kWarning(30518) << "Unsupported lineSpacingType: " << layout.lineSpacingType << " (Ignoring!)";
                 break;
             }
         }
@@ -1916,13 +1913,13 @@ QString OOWriterWorker::layoutToParagraphStyle(const LayoutData& layoutOrigin,
         styleKey += 'A';
     }
 
-    styleKey += '@'; // A more visible seperator
+    styleKey += '@'; // A more visible separator
 
     props += textFormatToStyle(layoutOrigin.formatData.text,layout.formatData.text,force,styleKey);
 
-    props += ">";
+    props += '>';
 
-    styleKey += '@'; // A more visible seperator
+    styleKey += '@'; // A more visible separator
 
     // ### TODO/FIXME: what if all tabulators must be erased?
     if (!layout.tabulatorList.isEmpty()
@@ -1939,11 +1936,11 @@ QString OOWriterWorker::layoutToParagraphStyle(const LayoutData& layoutOrigin,
             styleKey += QString::number((*it).m_ptpos);
             switch ((*it).m_type)
             {
-                case 0:  props += " style:type=\"left\""; styleKey += "L"; break;
-                case 1:  props += " style:type=\"center\""; styleKey += "C"; break;
-                case 2:  props += " style:type=\"right\""; styleKey += "R"; break;
-                case 3:  props += " style:type=\"char\" style:char=\".\""; styleKey += "D"; break; // decimal
-                default: props += " style:type=\"left\""; styleKey += "L"; break;
+                case 0:  props += " style:type=\"left\""; styleKey += 'L'; break;
+                case 1:  props += " style:type=\"center\""; styleKey += 'C'; break;
+                case 2:  props += " style:type=\"right\""; styleKey += 'R'; break;
+                case 3:  props += " style:type=\"char\" style:char=\".\""; styleKey += 'D'; break; // decimal
+                default: props += " style:type=\"left\""; styleKey += 'L'; break;
             }
             switch ((*it).m_filling) // ### TODO: check if the characters are right
             {
@@ -1989,16 +1986,16 @@ bool OOWriterWorker::doFullParagraph(const QString& paraText, const LayoutData&
     QString actualStyle(layout.styleName);
     if (!props.isEmpty())
     {
-        QMap<QString,QString>::ConstIterator it ( m_mapParaStyleKeys.find(styleKey) );
-        kdDebug(30518) << "Searching paragraph key: " << styleKey << endl;
+        QMap<QString,QString>::ConstIterator it ( m_mapParaStyleKeys.constFind(styleKey) );
+        kDebug(30518) <<"Searching paragraph key:" << styleKey;
 
         QString automaticStyle;
 
-        if (it==m_mapParaStyleKeys.end())
+        if (it==m_mapParaStyleKeys.constEnd())
         {
             // We have additional properties, so we need an automatic style for the paragraph
             automaticStyle = makeAutomaticStyleName("P", m_automaticParagraphStyleNumber);
-            kdDebug(30518) << "Creating automatic paragraph style: " << automaticStyle << " key: " << styleKey << endl;
+            kDebug(30518) <<"Creating automatic paragraph style:" << automaticStyle <<" key:" << styleKey;
             m_mapParaStyleKeys[styleKey]=automaticStyle;
 
             m_contentAutomaticStyles += "  <style:style";
@@ -2015,7 +2012,7 @@ bool OOWriterWorker::doFullParagraph(const QString& paraText, const LayoutData&
         {
             // We have a match, so use the already defined automatic paragraph style
             automaticStyle=it.data();
-            kdDebug(30518) << "Using automatic paragraph style: " << automaticStyle << " key: " << styleKey << endl;
+            kDebug(30518) <<"Using automatic paragraph style:" << automaticStyle <<" key:" << styleKey;
         }
 
         actualStyle=automaticStyle;
@@ -2027,7 +2024,7 @@ bool OOWriterWorker::doFullParagraph(const QString& paraText, const LayoutData&
     }
     else
     {   // SHould not happen
-        kdWarning(30518) << "No style for a paragraph!" << endl;
+        kWarning(30518) << "No style for a paragraph!";
     }
 
     *m_streamOut << ">";
@@ -2069,7 +2066,7 @@ bool OOWriterWorker::doFullDefineStyle(LayoutData& layout)
 
     QString debugKey; // Not needed
     m_styles += layoutToParagraphStyle(layout,layout,true,debugKey);
-    kdDebug(30518) << "Defining style: " << debugKey << endl;
+    kDebug(30518) <<"Defining style:" << debugKey;
 
     m_styles += "</style:properties>\n";
     m_styles += "  </style:style>\n";
@@ -2090,16 +2087,11 @@ bool OOWriterWorker::doFullPaperFormat(const int format,
         || ( width < 1.0 )
         || ( height < 1.0 ) )
     {
-        kdWarning(30518) << "Page size problem: format: " << format << " width: " << width << " height: " << height << endl;
+        kWarning(30518) << "Page size problem: format: " << format << " width: " << width << " height: " << height;
         // Something is wrong with the page size
-        KoFormat newFormat = KoFormat ( format );
-        if ( ( format < 0 ) || ( format > PG_LAST_FORMAT ) )
-        {
-            // Bad or unknown format, so assume ISO A4
-            newFormat = PG_DIN_A4;
-        }
-        m_paperWidth = KoPageFormat::width ( newFormat, KoOrientation( orientation ) ) * 72.0 / 25.4 ;
-        m_paperHeight = KoPageFormat::height ( newFormat, KoOrientation( orientation ) ) * 72.0 / 25.4 ;
+        KoPageFormat::Format newFormat = KoPageFormat::Format ( format );
+        m_paperWidth = KoPageFormat::width ( newFormat, KoPageFormat::Orientation( orientation ) ) * 72.0 / 25.4 ;
+        m_paperHeight = KoPageFormat::height ( newFormat, KoPageFormat::Orientation( orientation ) ) * 72.0 / 25.4 ;
         m_paperFormat = newFormat;
     }
     else
@@ -2108,7 +2100,7 @@ bool OOWriterWorker::doFullPaperFormat(const int format,
         m_paperWidth=width;
         m_paperHeight=height;
     }
-    m_paperOrientation=orientation; // ### TODO: check if OOWriter needs the orignal size (without landscape) or the real size
+    m_paperOrientation=orientation; // ### TODO: check if OOWriter needs the original size (without landscape) or the real size
     return true;
 }
 
@@ -2144,7 +2136,7 @@ bool OOWriterWorker::doVariableSettings(const VariableSettingsData& vs)
     return true;
 }
 
-bool OOWriterWorker::doDeclareNonInlinedFramesets( QValueList<FrameAnchor>& pictureAnchors, QValueList<FrameAnchor>& tableAnchors )
+bool OOWriterWorker::doDeclareNonInlinedFramesets( Q3ValueList<FrameAnchor>& pictureAnchors, Q3ValueList<FrameAnchor>& tableAnchors )
 {
     m_nonInlinedPictureAnchors = pictureAnchors;
     m_nonInlinedTableAnchors = tableAnchors;
@@ -2219,11 +2211,11 @@ QString OOWriterWorker::makeAutomaticStyleName(const QString& prefix, ulong& cou
     // If it is still not unique, try a time stamp.
     const QDateTime dt(QDateTime::currentDateTime(Qt::UTC));
 
-    str2 = str + "_" + QString::number(dt.toTime_t(),16);
+    str2 = str + '_' + QString::number(dt.toTime_t(),16);
     if (m_styleMap.find(str2)==m_styleMap.end())
         return str2;
 
-    kdWarning(30518) << "Could not make an unique style name: " << str2 << endl;
+    kWarning(30518) << "Could not make an unique style name: " << str2;
     return str2; // Still return, as we have nothing better
 }
 
