@@ -24,16 +24,18 @@
 
 #include "pdfdocument.h"
 #include "dialog.h"
+//Added by qt3to4:
+#include <QByteArray>
 
 
 class PdfImport : public KoFilter
 {
     Q_OBJECT
 public:
-    PdfImport(KoFilter *parent, const char *name, const QStringList&);
+    PdfImport(QObject* parent, const QStringList&);
 
     KoFilter::ConversionStatus
-    convert(const QCString& from, const QCString& to);
+    convert(const QByteArray& from, const QByteArray& to);
 
 private:
     void treatInfoDocument();
