@@ -15,14 +15,18 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
+
 #include "kis_label_cursor_pos.h"
+
 #include "kis_label_cursor_pos.moc"
 
-KisLabelCursorPos::KisLabelCursorPos(QWidget *parent, const char *name, WFlags f) : super(parent, name, f)
+KisLabelCursorPos::KisLabelCursorPos(QWidget *parent, const char *name, Qt::WFlags f)
+        : QLabel(parent, f)
 {
+    setObjectName(name);
     setText("0:0");
     m_doUpdates = true;
-    
+
     //setMinimumSize( 200, parent->height() - 4);
 }
 
@@ -30,7 +34,7 @@ KisLabelCursorPos::~KisLabelCursorPos()
 {
 }
 
-void KisLabelCursorPos::updatePos(Q_INT32 xpos, Q_INT32 ypos)
+void KisLabelCursorPos::updatePos(qint32 xpos, qint32 ypos)
 {
     if (m_doUpdates) {
         QString s;
@@ -48,6 +52,6 @@ void KisLabelCursorPos::enter()
 void KisLabelCursorPos::leave()
 {
     m_doUpdates = false;
-    setText(QString::null);
+    setText(QString());
 }
 
